Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/mono/libgit2.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorVicent Marti <tanoku@gmail.com>2014-06-20 16:42:16 +0400
committerVicent Marti <tanoku@gmail.com>2014-06-20 16:42:16 +0400
commit28f087c8642ff9c8dd6964e101e6d8539db6281a (patch)
tree3518d1bf420e92c964bed03074575d8a1db88654 /include/git2/branch.h
parent4b0a36e881506a02b43a4ae3c19c93c919b36eeb (diff)
parent1589aa0c4d48fb130d8a5db28c45cd3d173cde6d (diff)
libgit2 v0.21.0v0.21.0
Diffstat (limited to 'include/git2/branch.h')
-rw-r--r--include/git2/branch.h60
1 files changed, 32 insertions, 28 deletions
diff --git a/include/git2/branch.h b/include/git2/branch.h
index 44d6fd9c3..f28410000 100644
--- a/include/git2/branch.h
+++ b/include/git2/branch.h
@@ -43,6 +43,12 @@ GIT_BEGIN_DECL
*
* @param force Overwrite existing branch.
*
+ * @param signature The identity that will used to populate the reflog entry
+ *
+ * @param log_message The one line long message to be appended to the reflog.
+ * If NULL, the default is "Branch: created"; if you want something more
+ * useful, provide a message.
+ *
* @return 0, GIT_EINVALIDSPEC or an error code.
* A proper reference is written in the refs/heads namespace
* pointing to the provided target commit.
@@ -52,7 +58,9 @@ GIT_EXTERN(int) git_branch_create(
git_repository *repo,
const char *branch_name,
const git_commit *target,
- int force);
+ int force,
+ const git_signature *signature,
+ const char *log_message);
/**
* Delete an existing branch reference.
@@ -76,7 +84,7 @@ typedef struct git_branch_iterator git_branch_iterator;
* @param repo Repository where to find the branches.
* @param list_flags Filtering flags for the branch
* listing. Valid values are GIT_BRANCH_LOCAL, GIT_BRANCH_REMOTE
- * or a combination of the two.
+ * or GIT_BRANCH_ALL.
*
* @return 0 on success or an error code
*/
@@ -115,13 +123,19 @@ GIT_EXTERN(void) git_branch_iterator_free(git_branch_iterator *iter);
*
* @param force Overwrite existing branch.
*
+ * @param signature The identity that will used to populate the reflog entry
+ *
+ * @param log_message The one line long message to be appended to the reflog
+ *
* @return 0 on success, GIT_EINVALIDSPEC or an error code.
*/
GIT_EXTERN(int) git_branch_move(
git_reference **out,
git_reference *branch,
const char *new_branch_name,
- int force);
+ int force,
+ const git_signature *signature,
+ const char *log_message);
/**
* Lookup a branch by its name in a repository.
@@ -165,8 +179,9 @@ GIT_EXTERN(int) git_branch_lookup(
* @return 0 on success; otherwise an error code (e.g., if the
* ref is no local or remote branch).
*/
-GIT_EXTERN(int) git_branch_name(const char **out,
- git_reference *ref);
+GIT_EXTERN(int) git_branch_name(
+ const char **out,
+ const git_reference *ref);
/**
* Return the reference supporting the remote tracking branch,
@@ -182,7 +197,7 @@ GIT_EXTERN(int) git_branch_name(const char **out,
*/
GIT_EXTERN(int) git_branch_upstream(
git_reference **out,
- git_reference *branch);
+ const git_reference *branch);
/**
* Set the upstream configuration for a given local branch
@@ -200,25 +215,20 @@ GIT_EXTERN(int) git_branch_set_upstream(git_reference *branch, const char *upstr
* Return the name of the reference supporting the remote tracking branch,
* given the name of a local branch reference.
*
- * @param tracking_branch_name_out The user-allocated buffer which will be
- * filled with the name of the reference. Pass NULL if you just want to
- * get the needed size of the name of the reference as the output value.
- *
- * @param buffer_size Size of the `out` buffer in bytes.
+ * @param out Pointer to the user-allocated git_buf which will be
+ * filled with the name of the reference.
*
* @param repo the repository where the branches live
*
* @param canonical_branch_name name of the local branch.
*
- * @return number of characters in the reference name
- * including the trailing NUL byte; GIT_ENOTFOUND when no remote tracking
- * reference exists, otherwise an error code.
+ * @return 0, GIT_ENOTFOUND when no remote tracking reference exists,
+ * otherwise an error code.
*/
GIT_EXTERN(int) git_branch_upstream_name(
- char *tracking_branch_name_out,
- size_t buffer_size,
+ git_buf *out,
git_repository *repo,
- const char *canonical_branch_name);
+ const char *refname);
/**
* Determine if the current local branch is pointed at by HEAD.
@@ -229,30 +239,24 @@ GIT_EXTERN(int) git_branch_upstream_name(
* error code otherwise.
*/
GIT_EXTERN(int) git_branch_is_head(
- git_reference *branch);
+ const git_reference *branch);
/**
* Return the name of remote that the remote tracking branch belongs to.
*
- * @param remote_name_out The user-allocated buffer which will be
- * filled with the name of the remote. Pass NULL if you just want to
- * get the needed size of the name of the remote as the output value.
- *
- * @param buffer_size Size of the `out` buffer in bytes.
+ * @param out Pointer to the user-allocated git_buf which will be filled iwth the name of the remote.
*
* @param repo The repository where the branch lives.
*
* @param canonical_branch_name name of the remote tracking branch.
*
- * @return Number of characters in the reference name
- * including the trailing NUL byte; GIT_ENOTFOUND
+ * @return 0, GIT_ENOTFOUND
* when no remote matching remote was found,
* GIT_EAMBIGUOUS when the branch maps to several remotes,
* otherwise an error code.
*/
GIT_EXTERN(int) git_branch_remote_name(
- char *remote_name_out,
- size_t buffer_size,
+ git_buf *out,
git_repository *repo,
const char *canonical_branch_name);
@@ -200,25 +215,20 @@ GIT_EXTERN(int) git_branch_set_upstream(git_reference *branch, const char *upstr
* @param repo the repository where the branches live
*
- * @param canonical_branch_name name of the local branch.
+ * @param refname reference name of the local branch.
*